@@ -4,7 +4,7 @@
 
 use crate::{
     basic::{mapx_ord_rawkey::MapxOrdRk, vecx_raw::VecxRaw},
-    common::utils::{hash, Hash, HASH_SIZ},
+    common::utils::hash::{hash, Hash, HASH_SIZ},
 };
 use serde::{Deserialize, Serialize};
 
